@@ -25,7 +25,7 @@ use CGI;
 use HTTP::Status qw(:constants :is);
 use HTTP::Headers;
 
-our $VERSION = q[2019.02.01];
+our $VERSION = q[2019.02.25];
 
 our $CRUD    = { # these map HTTP verbs to $action
 		POST    => 'create',
@@ -33,7 +33,7 @@ our $CRUD    = { # these map HTTP verbs to $action
 		PUT     => 'update',
 		DELETE  => 'delete',
                 OPTIONS => 'options',
-                HEAD    => 'null',
+                HEAD    => 'head',
                 TRACE   => 'null',
 	       };
 our $REST   = { # these assist sanitising $aspect
@@ -45,7 +45,8 @@ our $REST   = { # these assist sanitising $aspect
 	       edit    => 'GET',
 	       list    => 'GET',
                options => 'OPTIONS',
-               null    => 'HEAD|TRACE'
+               head    => 'HEAD',
+               null    => 'TRACE'
 	      };
 
 sub accept_extensions {
@@ -170,7 +171,7 @@ sub process_request { ## no critic (Subroutines::ProhibitExcessComplexity)
 
   my ($aspect)      = $pi =~ m{;(\S+)}smx;
 
-  if($action eq 'read' && !$id && !$aspect) {
+  if(($action eq 'read' || $action eq 'head') && !$id && !$aspect) {
     $aspect = 'list';
   }
 
@@ -257,7 +258,6 @@ sub process_request { ## no critic (Subroutines::ProhibitExcessComplexity)
 
     } else {
       $tmp = "${action}_$id";
-
     }
 
     $tmp =~ s/^read/list/smx;
@@ -316,7 +316,7 @@ sub process_request { ## no critic (Subroutines::ProhibitExcessComplexity)
     }
   }
 
-  if($aspect !~ /^(?:create|read|update|delete|add|list|edit|options)/smx) {
+  if($aspect !~ /^(?:create|read|update|delete|add|list|edit|options|head)/smx) {
     my $action_extended = $action;
     if(!$id) {
       $action_extended = {
