@@ -23,7 +23,7 @@ use MIME::Base64 qw(encode_base64);
 use JSON;
 use Readonly;
 
-our $VERSION = q[2019.02.01];
+our $VERSION = q[2019.02.25];
 
 our $DEBUG_OUTPUT        = 0;
 our $DEBUG_L10N          = 0;
@@ -318,7 +318,7 @@ sub render {
   # Figure out and call the appropriate action if available
   #
   my $method = $self->method_name;
-  if($method !~ /^(?:add|edit|create|read|update|delete|list|options)/smx) {
+  if($method !~ /^(?:add|edit|create|read|update|delete|list|options|head)/smx) {
     croak qq[Illegal method: $method];
   }
 
